; ISPRINTER() Printer status function for Clipper
;
; Written by Terry Carmen, Fido 260/338, Compuserve 72345,1533
;
; Usage: isprinter(printer port number)
; example, to test LPT1:   isprinter(1)
;
; returns .T. or .F. depending on if the printer is ready or not.
; 
; works on LPT1, 2, 3, 4
;
; Released to the public domain on 10/14/1991
;
; Remember to add isprinte.obj to your link command
;
; Compile with /mx /w2
;
;
public  isprinter
        
extrn   __parinfo:far
extrn   __parni:far
extrn   __retl:far

NOT_BUSY       equ 128
ACKNOWLEDGE    equ  64
OUT_OF_PAPER   equ  32
SELECTED       equ  16
IO_ERROR       equ   8
UNUSED         equ   4
ANOTHER_UNUSED equ   2
TIMEOUT        equ   1

_prog segment 'CODE'
assume  cs:_prog,ds:nothing,es:nothing

isprinter  proc far

                push    bp         
                mov     bp,sp     
                push    ds        
                push    es
                push    si
                push    di


                xor     ax,ax           
                push    ax
                call    __parinfo ; what kind of params do we have?
                add     sp,2            
                cmp     al,1      ; do we have one argument?
                jne     @@bad_exit    ; if not, we're out of here..

                mov     ax,1      ; top row
                push    ax        ; for Clipper's parni function
                call    __parni   ; we're looking for an integer
                add     sp,2      ; fix up the stack
                cmp     al,1      ; less than 1?
                jb      @@bad_exit    ; bye
                cmp     al,4      ; more than 4?
                jg      @@bad_exit    ; bye

                xor     dx,dx     ; clear out DX
                mov     dl, al    ; get the printer port (lpt1, 2, 3)
                dec     dx        ; the BIOS counts printers from 0
                mov ah, 02h       ; printer status function
                int 17h           ; call the BIOS

                cmp ah, NOT_BUSY + SELECTED
                je @@printer_ok

                mov ah, 0         ; not ready.... or something
                jmp short @@exit  ; so bug out...


@@printer_ok:   mov al, 1         ; true
                jmp short @@exit

@@bad_exit:     mov al, 0         ; false

@@exit:         mov ah, 0         ; clear out the top half of the register
                push ax
                call     __retl   ; return .T. or .F. 
                                  ; depending on the contents of ax
                add sp, 2         ; fix up the stack....

                pop     di
                pop     si
                pop     es        ; restore registers
                pop     ds                      
                pop     bp
                ret               ; far return to Clipper
                
isprinter       endp
_prog           ends
                end







